pub enum EngineCommand {
Show 30 variants
OrderAction(OrderActionMessage),
MarketAction(MarketActionCommand),
LiquidationState(LiquidationStateMessage),
TickExpiry {
now_ms: u64,
context: TickExpiryContext,
},
TickSnapshot {
now_ms: u64,
},
PriceUpdate {
underlying: String,
spot_price: Decimal,
timestamp_ms: u64,
},
IvUpdate {
underlying: String,
surface: VolatilitySurface,
journal_data: Option<Vec<u8>>,
timestamp_ms: u64,
},
TierUpdate {
wallet: WalletAddress,
margin_mode: MarginMode,
tier: String,
trading_limits: TradingLimits,
},
LegacyTierMarginModeUpdate {
wallet: WalletAddress,
margin_mode: MarginMode,
},
HypercorePositionUpdate {
account: String,
coin: String,
size: f64,
entry_price: f64,
unrealized_pnl: f64,
timestamp_ms: u64,
},
MmpConfigUpdate {
wallet: WalletAddress,
currency: String,
enabled: bool,
interval_ms: i64,
frozen_time_ms: i64,
qty_limit: Option<f64>,
delta_limit: Option<f64>,
vega_limit: Option<f64>,
},
RfqExecute(RfqExecuteCommand),
TradingModeUpdate {
modes: HashMap<String, TradingModes>,
timestamp_ms: u64,
},
DepositUpdate {
wallet: WalletAddress,
amount: Decimal,
timestamp_ms: u64,
sequence: Option<u64>,
source_event_hash: FixedBytes<32>,
},
OptionDepositUpdate {
request_id: String,
wallet: WalletAddress,
symbol: String,
quantity: Decimal,
timestamp_ms: u64,
},
OptionWithdrawalUpdate {
request_id: String,
wallet: WalletAddress,
account: WalletAddress,
signer: WalletAddress,
rsm_signer: WalletAddress,
symbol: String,
quantity: Decimal,
nonce: Option<u64>,
action: Vec<u8>,
timestamp_ms: u64,
},
CashWithdrawalUpdate {
request_id: String,
wallet: WalletAddress,
account: WalletAddress,
destination: WalletAddress,
signer: WalletAddress,
rsm_signer: WalletAddress,
amount: Decimal,
amount_wei: u64,
nonce: Option<u64>,
timestamp_ms: u64,
},
LiquidationBonusUpdate {
wallet: WalletAddress,
amount: Decimal,
balance_after: Decimal,
timestamp_ms: u64,
sequence: Option<u64>,
},
ApproveAgent {
wallet: WalletAddress,
agent: WalletAddress,
expires_at_ms: Option<u64>,
nonce: Option<u64>,
timestamp_ms: u64,
},
RevokeAgent {
wallet: WalletAddress,
agent: WalletAddress,
nonce: Option<u64>,
timestamp_ms: u64,
},
NonceAdvance {
wallet: WalletAddress,
nonce: u64,
timestamp_ms: u64,
},
HypercoreEquityUpdate {
wallet: WalletAddress,
account_value: Decimal,
timestamp_ms: u64,
},
SetPmSettlementPoolConfig(SetPmSettlementPoolConfigCommand),
RecordPmVaultDeposit(RecordPmVaultDepositCommand),
RequestPmVaultWithdrawal(RequestPmVaultWithdrawalCommand),
AccruePmSettlementInterest(AccruePmSettlementInterestCommand),
ApplyPmSettlementRepayment(ApplyPmSettlementRepaymentCommand),
JournalPmRecoveryPlan(JournalPmRecoveryPlanCommand),
MarkPmRecoveryActionSubmitted(MarkPmRecoveryActionSubmittedCommand),
ResolvePmRecoveryAction(ResolvePmRecoveryActionCommand),
}Expand description
Commands that mutate engine state.
Every state-affecting input enters the engine as one of these variants. Commands are the sole mechanism for state change, making the engine fully deterministic: the same command sequence always produces the same state.
Commands arrive from multiple sources in the runtime:
- REST API handlers produce
Order,MmpConfigUpdate,TierUpdate - Oracle feeds produce
PriceUpdate,IvUpdate - On-chain event listeners produce
DepositUpdate,HypercorePositionUpdate - Timer ticks produce
TickExpiry,TradingModeUpdate - Liquidation monitor produces
LiquidationState
Variants
OrderAction(OrderActionMessage)
MarketAction(MarketActionCommand)
LiquidationState(LiquidationStateMessage)
TickExpiry
TickSnapshot
PriceUpdate
IvUpdate
Fields

surface: VolatilitySurfaceTierUpdate
LegacyTierMarginModeUpdate
HypercorePositionUpdate
Fields
MmpConfigUpdate
Fields

wallet: WalletAddressRfqExecute(RfqExecuteCommand)
TradingModeUpdate
DepositUpdate
OptionDepositUpdate
OptionWithdrawalUpdate
Fields

wallet: WalletAddress
account: WalletAddress
signer: WalletAddress
rsm_signer: WalletAddress
quantity: DecimalCashWithdrawalUpdate
Fields

wallet: WalletAddress
account: WalletAddress
destination: WalletAddress
signer: WalletAddress
rsm_signer: WalletAddress
amount: DecimalLiquidationBonusUpdate
ApproveAgent
RevokeAgent
NonceAdvance
HypercoreEquityUpdate
SetPmSettlementPoolConfig(SetPmSettlementPoolConfigCommand)
RecordPmVaultDeposit(RecordPmVaultDepositCommand)
RequestPmVaultWithdrawal(RequestPmVaultWithdrawalCommand)
AccruePmSettlementInterest(AccruePmSettlementInterestCommand)
ApplyPmSettlementRepayment(ApplyPmSettlementRepaymentCommand)
JournalPmRecoveryPlan(JournalPmRecoveryPlanCommand)
MarkPmRecoveryActionSubmitted(MarkPmRecoveryActionSubmittedCommand)
ResolvePmRecoveryAction(ResolvePmRecoveryActionCommand)
Implementations
Sourceimpl EngineCommand
impl EngineCommand